==> nylas-production-python-0.2.1.tar.gz: nylas-production-python-0.2.1/nylas/logging/sentry/__init__.py <==
from pkgutil import extend_path

# Allow out-of-tree submodules.
__path__ = extend_path(__path__, __name__)

import raven
import raven.processors

from nylas.logging.log import get_logger, MAX_EXCEPTION_LENGTH

# Monkeypatch with values from your app's config to configure.
SENTRY_DSN = None

_sentry_client = None


def sentry_exceptions_enabled():
    return SENTRY_DSN is not None


def get_sentry_client():
    if _sentry_client is None:
        return raven.Client(
            SENTRY_DSN,
            processors=('nylas.logging.sentry.TruncatingProcessor',))
    return _sentry_client


class TruncatingProcessor(raven.processors.Processor):
    """Truncates the exception value string, and strips stack locals.
    Sending stack locals could potentially leak information."""

    # A whitelist of locals we don't want to strip.
    # They must be non-PII!
    locals_whitelist = ['account_id', 'message_id']

    # Note(emfree): raven.processors.Processor provides a filter_stacktrace
    # method to implement, but won't actually call it correctly. We can
    # simplify this if it gets fixed upstream.
    def process(self, data, **kwargs):
        if 'exception' not in data:
            return data
        if 'values' not in data['exception']:
            return data
        for item in data['exception']['values']:
            item['value'] = item['value'][:MAX_EXCEPTION_LENGTH]
            stacktrace = item.get('stacktrace')
            if stacktrace is not None:
                if 'frames' in stacktrace:
                    for frame in stacktrace['frames']:
                        for stack_local in frame['vars'].keys():
                            if stack_local not in self.locals_whitelist:
                                frame['vars'].pop(stack_local)
        return data


def sentry_alert(*args, **kwargs):
    if sentry_exceptions_enabled():
        get_sentry_client().captureException(*args, **kwargs)


def log_uncaught_errors(logger=None, **kwargs):
    """
    Helper to log uncaught exceptions.

    All additional kwargs supplied will be sent to Sentry as extra data.

    Parameters
    ----------
    logger: structlog.BoundLogger, optional
        The logging object to write to.

    """
    logger = logger or get_logger()
    logger.error('Uncaught error', exc_info=True, **kwargs)
    sentry_alert(extra=kwargs)

==> nylas-production-python-0.2.5.tar.gz: nylas-production-python-0.2.5/nylas/logging/sentry/__init__.py <==
from pkgutil import extend_path

# Allow out-of-tree submodules.
__path__ = extend_path(__path__, __name__)

import raven
import raven.processors

from nylas.logging.log import get_logger, MAX_EXCEPTION_LENGTH

# Monkeypatch with values from your app's config to configure.
SENTRY_DSN = None

_sentry_client = None


def sentry_exceptions_enabled():
    return SENTRY_DSN is not None


def get_sentry_client():
    if _sentry_client is None:
        return raven.Client(
            SENTRY_DSN,
            processors=('nylas.logging.sentry.TruncatingProcessor',))
    return _sentry_client


class TruncatingProcessor(raven.processors.Processor):
    """Truncates the exception value string"""

    # Note(emfree): raven.processors.Processor provides a filter_stacktrace
    # method to implement, but won't actually call it correctly. We can
    # simplify this if it gets fixed upstream.
    def process(self, data, **kwargs):
        if 'exception' not in data:
            return data
        if 'values' not in data['exception']:
            return data
        for item in data['exception']['values']:
            item['value'] = item['value'][:MAX_EXCEPTION_LENGTH]
        return data


def sentry_alert(*args, **kwargs):
    if sentry_exceptions_enabled():
        get_sentry_client().captureException(*args, **kwargs)


def log_uncaught_errors(logger=None, **kwargs):
    """
    Helper to log uncaught exceptions.

    All additional kwargs supplied will be sent to Sentry as extra data.

    Parameters
    ----------
    logger: structlog.BoundLogger, optional
        The logging object to write to.

    """
    logger = logger or get_logger()
    logger.error('Uncaught error', exc_info=True, **kwargs)
    sentry_alert(extra=kwargs)
